@@ -6,7 +6,7 @@ use 5.010;
 # ABSTRACT: App::TimeTracker Jira plugin
 use App::TimeTracker::Utils qw(error_message warning_message);
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 use Moose::Role;
 use JIRA::REST ();
@@ -75,16 +75,15 @@ before [ 'cmd_start', 'cmd_continue', 'cmd_append' ] => sub {
     my $ticket;
     if ( $self->jira_client ) {
         $ticket = $self->jira_ticket;
-        if ( defined $ticket ) {
-            if ( defined $self->description ) {
-                $self->description(
-                    sprintf(
-                        '%s (%s)', $self->description, $ticket->{fields}->{summary}
-                    ) );
-            }
-            else {
-                $self->description( $ticket->{fields}->{summary} // '' );
-            }
+        return unless defined $ticket;
+        if ( defined $self->description ) {
+            $self->description(
+                sprintf(
+                    '%s (%s)', $self->description, $ticket->{fields}->{summary}
+                ) );
+        }
+        else {
+            $self->description( $ticket->{fields}->{summary} // '' );
         }
     }
 
@@ -103,7 +102,7 @@ after [ 'cmd_start', 'cmd_continue', 'cmd_append' ] => sub {
     return unless $self->has_jira && $self->jira_client;
 
     my $ticket = $self->jira_ticket;
-    return unless $ticket;
+    return unless defined $ticket;
 
     if ( $self->config->{jira}->{set_status}{start}->{transition}
             and $self->config->{jira}->{set_status}{start}->{target_state} ) {
@@ -144,7 +143,7 @@ after 'cmd_stop' => sub {
     return unless $task_rounded_minutes > 0;
 
     my $ticket = $self->_init_jira_ticket($task);
-    if ( not $ticket ) {
+    if ( not defined $ticket ) {
         say
             'Last task did not contain a JIRA ticket id, not updating TimeWorked or Status.';
         return;
@@ -195,24 +194,26 @@ sub _init_jira_ticket {
     elsif ( $self->jira ) {
         $id = $self->jira;
     }
-
-    my $transitions;
-    try {
-        $transitions = $self->jira_client->GET(sprintf('/issue/%s/transitions',$id));
-    }
-    catch {
-        error_message( 'Could not fetch JIRA ticket transitions: %s', $transitions );
-    };
-    $self->jira_ticket_transitions( $transitions->{transitions} );
+    return unless defined $id;
 
     my $ticket;
     try {
         $ticket = $self->jira_client->GET(sprintf('/issue/%s',$id), { fields => '-comment' });
     }
     catch {
-        error_message( 'Could not fetch JIRA ticket: %s', $ticket );
+        error_message( 'Could not fetch JIRA ticket: %s', $id );
     };
 
+    my $transitions;
+    try {
+        $transitions = $self->jira_client->GET(sprintf('/issue/%s/transitions',$id));
+    }
+    catch {
+        require Data::Dumper;
+        error_message( 'Could not fetch JIRA transitions for %s: %s', $id, Data::Dumper::Dumper $transitions );
+    };
+    $self->jira_ticket_transitions( $transitions->{transitions} );
+
     return $ticket;
 }
 
@@ -221,13 +222,25 @@ sub _check_resolve_ticket_transition {
     my $transition_id;
 
     foreach my $transition ( @{$self->jira_ticket_transitions} ) {
-        if ( $transition->{name} eq $status_name ) {
+        if ( ref $status_name and ref $status_name eq 'ARRAY' ) {
+            foreach my $name ( @$status_name ) {
+                if ( $transition->{name} eq $name ) {
+                    $transition_id = $transition->{id};
+                    last;
+                }
+            }
+        }
+        elsif ( $transition->{name} eq $status_name ) {
             $transition_id = $transition->{id};
             last;
         }
     }
     if ( not defined $transition_id ) {
-        error_message( 'Could not resolve "%s" as valid JIRA ticket transition', $status_name );
+        require Data::Dumper;
+        error_message( 'None of the configured ticket transitions (%s) did match the ones valid for this JIRA ticket\'s workflow-state: %s',
+            ref $status_name ? join(',', map { '"'.$_.'"' } @$status_name) : $status_name,
+            join(',', map { '"'.$_->{name}.'"' } @{$self->jira_ticket_transitions} ),
+        );
         return;
     }
     return $transition_id;
@@ -239,6 +252,7 @@ sub App::TimeTracker::Data::Task::jira_id {
         next unless $tag =~ /^JIRA:(.+)/;
         return $1;
     }
+    return;
 }
 
 sub _safe_ticket_subject {
@@ -268,7 +282,7 @@ App::TimeTracker::Command::Jira - App::TimeTracker Jira plugin
 
 =head1 VERSION
 
-version 0.4
+version 0.5
 
 =head1 DESCRIPTION
 
@@ -350,7 +364,7 @@ If <set_status/stop/transition> is set in config and the current Jira ticket sta
             "log_time_spent" : "1",
             "server_url" : "http://localhost:8080",
             "set_status": {
-                "start": { "transition": "Start Progress", "target_state": "In Progress" },
+                "start": { "transition": ["Start Progress", "Restart progress", "Reopen and start progress"], "target_state": "In Progress" },
                 "stop": { "transition": "Stop Progress" }
             }
         }
@@ -362,7 +376,7 @@ Michael Kröll <pepl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Michael Kröll.
+This software is copyright (c) 2016 by Michael Kröll.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
